@@ -61,7 +61,7 @@ sub add_index {
     return if $self->_maybe_index_from_metacpan( $index, $archive_file );
 
     my $archive = Archive::Extract->new( archive => $archive_file );
-    my $tmpdir = tempdir( CLEANUP => 1 );
+    my $tmpdir = tempdir( 'orepan2.XXXXXX', TMPDIR => 1, CLEANUP => 1 );
     $archive->extract( to => $tmpdir );
 
     my $provides = $self->scan_provides( $tmpdir, $archive_file );
@@ -103,7 +103,8 @@ sub scan_provides {
         }
     }
 
-    print STDERR "[INFO] Could not find useful meta from '$archive_file'\n";
+    print STDERR
+        "[INFO] Found META file in '$archive_file' but it does not contain 'provides'\n";
     print STDERR "[INFO] Scanning for provided modules...\n";
 
     my $provides = eval { $self->_scan_provides('.') };
@@ -190,7 +191,8 @@ sub do_metacpan_lookup {
 sub _scan_provides {
     my ( $self, $dir, $meta ) = @_;
 
-    my $provides = Parse::LocalDistribution->new->parse($dir);
+    my $provides = Parse::LocalDistribution->new( { ALLOW_DEV_VERSION => 1 } )
+        ->parse($dir);
     return $provides;
 }
 
